@@ -1,8 +1,7 @@
 /****************************************************************************
 **
 ** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Contact: http://www.qt-project.org/
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -35,6 +34,7 @@
 **
 **
 **
+**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -1036,8 +1036,11 @@ bool QFile::open(OpenMode mode)
 #endif
     {
         QIODevice::open(mode);
-        if (mode & Append)
-            seek(size());
+        if (mode & Append) {
+            //The file engine should have done this in open(),
+            //this is a workaround for backward compatibility
+            fileEngine()->seek(size());
+        }
         return true;
     }
     QFile::FileError err = d->fileEngine->error();
