@@ -1,8 +1,7 @@
 /****************************************************************************
 **
 ** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Contact: http://www.qt-project.org/
 **
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
@@ -35,6 +34,7 @@
 **
 **
 **
+**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -1056,8 +1056,10 @@ QDeclarativeItem *QDeclarativeVisualDataModel::item(int index, const QByteArray
         QDeclarativeVisualDataModelData *data = new QDeclarativeVisualDataModelData(index, this);
         if ((!d->m_listModelInterface || !d->m_abstractItemModel) && d->m_listAccessor
             && d->m_listAccessor->type() == QDeclarativeListAccessor::ListProperty) {
-            ctxt->setContextObject(d->m_listAccessor->at(index).value<QObject*>());
-            ctxt = new QDeclarativeContext(ctxt, ctxt);
+            QDeclarativeContext *objCtxt = ctxt;
+            objCtxt->setContextObject(d->m_listAccessor->at(index).value<QObject*>());
+            ctxt = new QDeclarativeContext(ctxt);
+            QDeclarative_setParent_noEvent(objCtxt, ctxt);
         }
         ctxt->setContextProperty(QLatin1String("model"), data);
         ctxt->setContextObject(data);
